@@ -1,9 +1,14 @@
 import traceback
 # pip dependency
-from termcolor import cprint
+try:
+    from termcolor import cprint
+except ImportError:
+    # Fallback: When termcolor is not installed, just print everything without color
+    def cprint(message, *args, **kwargs) -> None:
+        print(message)
 
 # @SYNC: /setup.cfg -> [metadata] -> version
-__version__ = "0.2.6"
+__version__ = "0.3.0"
 
 
 class DoNotPrintMeException(Exception):
@@ -24,7 +29,8 @@ def print_error(message, print_stacktrace: bool = False, raise_error: bool = Fal
 
 
 def get_name_and_version() -> tuple[str, str]:
-    package_name = __package__
+    # Use the pip name instead of the package name
+    package_name = "shell-command-logger"
     package_version = __version__
 
     return (package_name, package_version)
